@@ -26,7 +26,6 @@ from sagemaker.fw_utils import (
     validate_version_or_image_args,
     warn_if_parameter_server_with_multi_gpu,
     validate_smdistributed,
-    get_mp_parameters,
 )
 from sagemaker.pytorch import defaults
 from sagemaker.pytorch.model import PyTorchModel
@@ -51,8 +50,7 @@ class PyTorch(Framework):
         distribution=None,
         **kwargs
     ):
-        """
-        This ``Estimator`` executes an PyTorch script in a managed PyTorch execution environment.
+        """This ``Estimator`` executes a PyTorch script in a managed PyTorch execution environment.
 
         The managed PyTorch environment is an Amazon-built Docker container that executes functions
         defined in the supplied ``entry_point`` Python script within a SageMaker Training Job.
@@ -191,39 +189,9 @@ class PyTorch(Framework):
     def hyperparameters(self):
         """Return hyperparameters used by your custom PyTorch code during model training."""
         hyperparameters = super(PyTorch, self).hyperparameters()
-        additional_hyperparameters = {}
-
-        if "parameter_server" in self.distribution:
-            ps_enabled = self.distribution.get("parameter_server").get("enabled", False)
-            additional_hyperparameters[self.LAUNCH_PS_ENV_NAME] = ps_enabled
-
-        if "mpi" in self.distribution:
-            mpi_dict = self.distribution["mpi"]
-            mpi_enabled = mpi_dict.get("enabled", False)
-            additional_hyperparameters[self.LAUNCH_MPI_ENV_NAME] = mpi_enabled
-
-            if mpi_dict.get("processes_per_host"):
-                additional_hyperparameters[self.MPI_NUM_PROCESSES_PER_HOST] = mpi_dict.get(
-                    "processes_per_host"
-                )
-
-            additional_hyperparameters[self.MPI_CUSTOM_MPI_OPTIONS] = mpi_dict.get(
-                "custom_mpi_options", ""
-            )
-
-            if get_mp_parameters(self.distribution):
-                additional_hyperparameters["mp_parameters"] = get_mp_parameters(self.distribution)
-
-        elif "modelparallel" in self.distribution.get("smdistributed", {}):
-            raise ValueError("Cannot use Model Parallelism without MPI enabled!")
-
-        if "smdistributed" in self.distribution:
-            # smdistributed strategy selected
-            smdistributed = self.distribution["smdistributed"]
-            smdataparallel_enabled = smdistributed.get("dataparallel", {}).get("enabled", False)
-            additional_hyperparameters[self.LAUNCH_SM_DDP_ENV_NAME] = smdataparallel_enabled
-            additional_hyperparameters[self.INSTANCE_TYPE] = self.instance_type
-
+        additional_hyperparameters = self._distribution_configuration(
+            distribution=self.distribution
+        )
         hyperparameters.update(Framework._json_encode_hyperparameters(additional_hyperparameters))
         return hyperparameters
 
